local OUTPUT_STRING = "%s looted in combat."

local roster = AceLibrary("Roster-2.1").roster
local classColors = setmetatable({}, {__index =
	function(self, key)
		local r, g, b = 0.63, 0.63, 0.63
		if RAID_CLASS_COLORS and RAID_CLASS_COLORS[key] then
			r, g, b = RAID_CLASS_COLORS[key].r, RAID_CLASS_COLORS[key].g, RAID_CLASS_COLORS[key].b
		end
		self[key] = "|cff" .. string.format("%02x%02x%02x", r * 255, g * 255, b * 255)
		return self[key]
	end
})
local coloredName = setmetatable({}, {__index =
	function(self, key)
		if type(key) == "nil" then return nil end
		local class = roster[key] and roster[key].class or "NO_CLASS"
		self[key] = classColors[class] .. key .. "|r"
		return self[key]
	end
})

LootWhore = AceLibrary("AceAddon-2.0"):new("AceDB-2.0", "AceEvent-2.0", "AceConsole-2.0", "Sink-1.0")

local channels = {"Say", "Party", "Battleground", "Raid", "Raid Warning", "Guild", "Officer", "Yell"}
local function getChatChannels()
	return channels
end

local channelMapping = {
	["Say"] = "SAY",
	["Party"] = "PARTY",
	["Battleground"] = "BATTLEGROUND",
	["Guild"] = "GUILD",
	["Officer"] = "OFFICER",
	["Yell"] = "YELL",
	["Raid"] = "RAID",
	["Raid Warning"] = "RAID_WARNING",
}
local sink = AceLibrary("Sink-1.0")
local function doChatOutput(addon, text, r, g, b, font, size, outline, sticky, loc)
	local location = sink.storageForAddon[addon] and sink.storageForAddon[addon].sink10ScrollArea or "Say"
	-- We can't use colors in chat, so remove any color definitions
	text = text:gsub("(|c%x%x%x%x%x%x%x%x)", "")
	text = text:gsub("(|r)", "")
	SendChatMessage(text, channelMapping[location] or "SAY")
end

function LootWhore:OnInitialize()
	self:RegisterDB("LootWhoreDB")
	self:RegisterDefaults("profile", {
		sink10OutputSink = "Chat",
		sink10ScrollArea = "Say",
	})

	self:RegisterSink("Chat", "Chat channel", "Route output from this addon through a chat channel, making it visible to all the members of the channel.", doChatOutput, getChatChannels)

	self:RegisterChatCommand("/lootwhore", {
		type = "group",
		name = "LootWhore",
		desc = "LootWhore options.",
		args = {},
	}, "LOOTWHORE")
end

function LootWhore:OnEnable()
	self:RegisterEvent("CHAT_MSG_ADDON")
end

function LootWhore:CHAT_MSG_ADDON(prefix, message, distribution, sender)
	if prefix ~= "LOOT_OPENED" or not InCombatLockdown() or not roster[sender] then return end
	-- Find the zone of the person and check it against our own zone, if they're
	-- different, don't pour anything.
	if UnitInRaid("player") then
		-- Not sure how to find the zone info of a party member yet, only raid
		-- members.
		local id = select(3, roster[sender].unitid:find("(%d+)"))
		if id then
			local senderZone = select(7, GetRaidRosterInfo(id))
			if senderZone ~= GetRealZoneText() and senderZone ~= GetZoneText() then return end
		end
	end
	self:Pour(OUTPUT_STRING:format(coloredName[sender]))
end

